@@ -1,5 +1,6 @@
 import click
 
+from .backup import encrypted_database_backup
 from .inspect import inspect
 from .reset import reset
 from .scan import scan
@@ -12,6 +13,7 @@ def cli():
     pass
 
 
+cli.add_command(encrypted_database_backup)
 cli.add_command(inspect)
 cli.add_command(reset)
 cli.add_command(scan)
